/***
 ** @author: Ben Y. Zhao (ravenben@cs.berkeley.edu)
 ** @version: Release 2.0 CVS: $Revision: 1.4 $  Date: $Date: 2000/01/06 21:19:18 $
 ** (c) 2000 by Ben Yanbin Zhao and the Regents of the University of California
 ** This is a simple integer counter class, which provides synchronized 
 ** access to an integer counter.  To be used for sequencer functionality.
 ** The value starts at 0, and a copy of the current counter is returned before
 ** the real value is incremented.
 **/

package ninja.xset;

public class Counter implements java.io.Serializable {
  private long count;

  /***************
   ** Counter() **
   ***************
   ** Constructor method, creates new counter variable
   **/
  public Counter() {
    count =  0;
  }

  /*******************
   ** Counter(long) **
   *******************
   ** Constructor method starting with an initial value.
   ** This is useful for recovering to a previous state and 
   ** creating a counter with the correct sequence #.
   ** It will not accept a negative initial value, and sets
   ** the value to 0 in that case.
   **/
  public Counter(long initialValue) {
    if (initialValue < 0) count = 0;
    else count = initialValue;
  }

  /*************************
   ** long getNextCount() **
   *************************
   ** Method to return a new counter value.  It also internally 
   ** increments the value after making a copy of the current counter
   ** for being returned.
   ** @return The next counter value
   **/
  public synchronized long getNextCount() {
    long value = count;
    count++;
    return value;
  }

  /**********************
   ** long currCount() **
   **********************
   ** Get the current counter without incrementing the value
   ** Useful for getting the number of counter values given out
   ** @return The number of counter values given out = next new value
   **/
  public long currCount() {
    return count;
  }

  /******************
   ** void reset() **
   ******************
   ** Resets the counter value to 0
   **/
  public synchronized void reset() {
    count = 0;
  }

  public synchronized void setValue(long newValue) {
    count = newValue;
  }
}
